@@ -7,10 +7,6 @@ import decimal
 from cymysql.constants import FIELD_TYPE
 
 PYTHON3 = sys.version_info[0] > 2
-if PYTHON3:
-    # suppress flake8 error
-    long = int
-    unicode = str
 
 ESCAPE_REGEX = re.compile(r"[\0\n\r\032\'\"\\]")
 ESCAPE_MAP = {'\0': '\\0', '\n': '\\n', '\r': '\\r', '\032': '\\Z',
@@ -289,7 +285,9 @@ def convert_characters(data, encoding=None, field=None, use_unicode=None):
 
 
 def convert_json(data, encoding=None, field=None, use_unicode=None):
-    return data.decode(encoding)
+    if use_unicode or PYTHON3:
+        return data.decode(field.encoding)
+    return data
 
 
 def convert_decimal(obj):
