@@ -5,7 +5,7 @@ import sys
 import struct
 from cymysql.err import raise_mysql_exception, OperationalError
 from cymysql.constants import SERVER_STATUS, FLAG
-from cymysql.converters import convert_characters
+from cymysql.converters import convert_characters, convert_json
 from cymysql.charset import charset_by_id, encoding_by_charset
 
 PYTHON3 = sys.version_info[0] > 2
@@ -150,7 +150,7 @@ class MysqlPacket(object):
         return tuple([
             None if value is None
             else decoder(value, self._encoding, field, self._use_unicode)
-            if decoder is convert_characters
+            if decoder in (convert_characters, convert_json)
             else decoder(value)
             for value, field, decoder in [
                 (self._read_length_coded_string(), f, decoders.get(f.type_code))
